import React, { CSSProperties, HTMLAttributes, MouseEvent } from 'react';
import { Elements, NodeTypesType, EdgeTypesType, OnLoadFunc, Node, Edge, Connection, ConnectionLineType } from '../../types';
import '../../style.css';
export interface ReactFlowProps extends Omit<HTMLAttributes<HTMLDivElement>, 'onLoad'> {
    elements: Elements;
    onElementClick?: (element: Node | Edge) => void;
    onElementsRemove?: (elements: Elements) => void;
    onNodeMouseEnter?: (evt: MouseEvent, node: Node) => void;
    onNodeMouseMove?: (evt: MouseEvent, node: Node) => void;
    onNodeMouseLeave?: (evt: MouseEvent, node: Node) => void;
    onNodeContextMenu?: (evt: MouseEvent, node: Node) => void;
    onNodeDragStart?: (node: Node) => void;
    onNodeDragStop?: (node: Node) => void;
    onConnect?: (connection: Edge | Connection) => void;
    onLoad?: OnLoadFunc;
    onMove?: () => void;
    onSelectionChange?: (elements: Elements | null) => void;
    nodeTypes: NodeTypesType;
    edgeTypes: EdgeTypesType;
    connectionLineType: ConnectionLineType;
    connectionLineStyle?: CSSProperties;
    deleteKeyCode: number;
    selectionKeyCode: number;
    snapToGrid: boolean;
    snapGrid: [number, number];
    onlyRenderVisibleNodes: boolean;
    nodesDraggable: boolean;
    nodesConnectable: boolean;
    elementsSelectable: boolean;
    selectNodesOnDrag: boolean;
    minZoom: number;
    maxZoom: number;
    defaultZoom: number;
    arrowHeadColor: string;
    markerEndId?: string;
    zoomOnScroll: boolean;
}
declare const ReactFlow: {
    ({ style, onElementClick, elements, className, children, nodeTypes, edgeTypes, onLoad, onMove, onElementsRemove, onConnect, onNodeMouseEnter, onNodeMouseMove, onNodeMouseLeave, onNodeContextMenu, onNodeDragStart, onNodeDragStop, onSelectionChange, connectionLineType, connectionLineStyle, deleteKeyCode, selectionKeyCode, snapToGrid, snapGrid, onlyRenderVisibleNodes, nodesDraggable, nodesConnectable, elementsSelectable, selectNodesOnDrag, minZoom, maxZoom, defaultZoom, arrowHeadColor, markerEndId, zoomOnScroll }: ReactFlowProps): JSX.Element;
    displayName: string;
    defaultProps: {
        nodeTypes: {
            input: React.MemoExoticComponent<({ data, isConnectable, sourcePosition }: import("../../types").NodeProps) => JSX.Element>;
            default: React.MemoExoticComponent<({ data, isConnectable, targetPosition, sourcePosition }: import("../../types").NodeProps) => JSX.Element>;
            output: React.MemoExoticComponent<({ data, isConnectable, targetPosition }: import("../../types").NodeProps) => JSX.Element>;
        };
        edgeTypes: {
            default: React.MemoExoticComponent<({ sourceX, sourceY, targetX, targetY, sourcePosition, targetPosition, label, labelStyle, labelShowBg, labelBgStyle, style, arrowHeadType, markerEndId, }: import("../../types").EdgeBezierProps) => JSX.Element>;
            straight: React.MemoExoticComponent<({ sourceX, sourceY, targetX, targetY, label, labelStyle, labelShowBg, labelBgStyle, style, arrowHeadType, markerEndId, }: import("../../types").EdgeProps) => JSX.Element>;
            step: React.MemoExoticComponent<({ sourceX, sourceY, targetX, targetY, label, labelStyle, labelShowBg, labelBgStyle, style, arrowHeadType, markerEndId, }: import("../../types").EdgeProps) => JSX.Element>;
            smoothstep: React.MemoExoticComponent<({ sourceX, sourceY, targetX, targetY, label, labelStyle, labelShowBg, labelBgStyle, style, sourcePosition, targetPosition, arrowHeadType, markerEndId, }: import("../../types").EdgeBezierProps) => JSX.Element>;
        };
        connectionLineType: ConnectionLineType;
        deleteKeyCode: number;
        selectionKeyCode: number;
        snapToGrid: boolean;
        snapGrid: number[];
        onlyRenderVisibleNodes: boolean;
        nodesDraggable: boolean;
        nodesConnectable: boolean;
        elementsSelectable: boolean;
        selectNodesOnDrag: boolean;
        minZoom: number;
        maxZoom: number;
        defaultZoom: number;
        arrowHeadColor: string;
        zoomOnScroll: boolean;
    };
};
export default ReactFlow;
