import { Action, Thunk } from 'easy-peasy';
import { Selection as D3Selection, ZoomBehavior } from 'd3';
import { ElementId, Elements, Transform, Node, Edge, Rect, Dimensions, XYPosition, OnConnectFunc, SelectionRect, HandleType, SetConnectionId, NodePosUpdate, FitViewParams } from '../types';
declare type TransformXYK = {
    x: number;
    y: number;
    k: number;
};
declare type NodeDimensionUpdate = {
    id: ElementId;
    nodeElement: HTMLDivElement;
};
declare type SelectionUpdate = {
    isActive: boolean;
    selection?: SelectionRect;
};
declare type SetMinMaxZoom = {
    minZoom: number;
    maxZoom: number;
};
declare type SetSnapGrid = {
    snapToGrid: boolean;
    snapGrid: [number, number];
};
export interface StoreModel {
    width: number;
    height: number;
    transform: Transform;
    nodes: Node[];
    edges: Edge[];
    selectedElements: Elements | null;
    selectedNodesBbox: Rect;
    d3Zoom: ZoomBehavior<Element, unknown> | null;
    d3Selection: D3Selection<Element, unknown, null, undefined> | null;
    d3Initialised: boolean;
    minZoom: number;
    maxZoom: number;
    nodesSelectionActive: boolean;
    selectionActive: boolean;
    selection: SelectionRect | null;
    userSelectionRect: SelectionRect;
    connectionNodeId: ElementId | null;
    connectionHandleType: HandleType | null;
    connectionPosition: XYPosition;
    snapToGrid: boolean;
    snapGrid: [number, number];
    nodesDraggable: boolean;
    nodesConnectable: boolean;
    elementsSelectable: boolean;
    reactFlowVersion: string;
    onConnect: OnConnectFunc;
    setOnConnect: Action<StoreModel, OnConnectFunc>;
    setNodes: Action<StoreModel, Node[]>;
    setEdges: Action<StoreModel, Edge[]>;
    updateNodeDimensions: Action<StoreModel, NodeDimensionUpdate>;
    updateNodePos: Action<StoreModel, NodePosUpdate>;
    setSelection: Action<StoreModel, boolean>;
    setNodesSelection: Action<StoreModel, SelectionUpdate>;
    setSelectedElements: Action<StoreModel, Elements | Node | Edge>;
    updateTransform: Action<StoreModel, TransformXYK>;
    updateSize: Action<StoreModel, Dimensions>;
    initD3: Action<StoreModel, Element>;
    setMinMaxZoom: Action<StoreModel, SetMinMaxZoom>;
    setSnapGrid: Action<StoreModel, SetSnapGrid>;
    setConnectionPosition: Action<StoreModel, XYPosition>;
    setConnectionNodeId: Action<StoreModel, SetConnectionId>;
    setInteractive: Action<StoreModel, boolean>;
    setNodesDraggable: Action<StoreModel, boolean>;
    setNodesConnectable: Action<StoreModel, boolean>;
    setElementsSelectable: Action<StoreModel, boolean>;
    setUserSelection: Action<StoreModel, XYPosition>;
    updateUserSelection: Action<StoreModel, XYPosition>;
    unsetUserSelection: Action<StoreModel>;
    fitView: Action<StoreModel, FitViewParams>;
    zoom: Action<StoreModel, number>;
    zoomIn: Thunk<StoreModel>;
    zoomOut: Thunk<StoreModel>;
}
export declare const storeModel: StoreModel;
declare const store: import("easy-peasy").Store<StoreModel, import("easy-peasy").EasyPeasyConfig<{}, any>>;
export default store;
